==> duiba-service-api-1.1-20160520.021025-92-sources.jar: cn/com/duiba/service/domain/dataobject/AppScheduledTasksDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

/**
 * app计划任务
 */
public class AppScheduledTasksDO extends BaseDO {
	private static final long serialVersionUID = 7893131267L;

	public static final String TYPE_VIRTUAL = "virtual";	//虚拟商品（仅限appItemDO使用）
	public static final String TYPE_COUPON = "coupon"; // 优惠券
	public static final String TYPE_OBJECT = "object"; // 实物
	public static final String TYPE_DUIBA_TURNTABLE = "duibaTurntable"; // 兑吧大转盘
	public static final String TYPE_DUIBA_SINGLE_LOTTERY = "duibaSingleLottery"; // 兑吧单品抽奖
	public static final String TYPE_DUIBA_ACTIVITY = "duibaActivity"; // 专题活动
	public static final String TYPE_APP_TURNTABLE = "appTurntable"; // 自有大转盘
	public static final String TYPE_APP_SINGLE_LOTTERY = "appSingleLottery"; // 自有单品抽奖
	public static final String TYPE_APP_MANUAL_LOTTERY = "appManualLottery"; // 自有手动开奖
	public static final String TYPE_DUIBA_SHAKE = "duibaShake";	// duiba摇一摇
	public static final String TYPE_APP_SHAKE = "appShake";	// app自有摇一摇
	public static final String TYPE_DUIBA_SCRATCH_CARD = "duibaScratch";//duiba刮刮乐
	public static final String TYPE_DUIBA_TIGER = "duibaTiger";//老虎机
	public static final String TYPE_APP_SCRATCH_CARD = "appScratch";//app刮刮乐
	public static final String TYPE_APP_TIGER = "appTiger";//老虎机
	public static final String TYPE_GAME_SANTA = "gameSanta";	// 游戏圣诞
	public static final String TYPE_GAME_YEAR_AWARD = "gameYearAward";	//数 年终奖
	public static final String TYPE_GAME_GIRL = "gameGirl";	// 女神游戏
	public static final String TYPE_DUIBA_SECONDS_KILL_ACTIVITY = "duibaSecondsKillActivity";	// 秒杀专题
	public static final String TYPE_DUIBA_QUESTION = "duibaQuestion";	// 兑吧答题活动
	public static final String TYPE_DUIBA_QUIZZ = "duibaQuizz";//兑吧测试题活动
	public static final String TYPE_DUIBA_SECKILL = "duibaSeckill";	// 兑吧秒杀活动

	public static final String SOURCE_TYPE_ITEM = "item"; // 来源item
	public static final String SOURCE_TYPE_ACTIVITY = "activity"; // 来源activity
	
	public static final String PLACE_BANNER = "placeBanner"; // banner
	public static final String PLACE_ITEM = "placeItem"; // item
	public static final String PLACE_BANNERANDITEM = "placeBannerAndItem"; // bannerAndItem
	
	public static final int EXCUTE_STATUS_REMOVE = 0;	// 移除
	public static final int EXCUTE_STATUS_WAIT_EXCUTE = 1;	// 待执行
	public static final int EXCUTE_STATUS_EXCUTE_SUCCESS = 2;	// 执行成功
	public static final int EXCUTE_STATUS_EXCUTE_FAIL = 3;	// 执行失败
	
	private Long id;

	private Long appId;

	private String type; // 定时内容类型

	private Long sourceId;

	private String sourceType; // 资源类型

	private String place;

	private Long duibaScheduledTaskId; // 兑吧任务ID

	private Date excuteTime; // 任务执行时间

	private Integer excuteStatus; // 执行状态

	private Date gmtCreate;

	private Date gmtModified;

	public AppScheduledTasksDO() {
	}
	
	public AppScheduledTasksDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public AppScheduledTasksDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			gmtCreate = new Date();
			gmtModified = gmtCreate;
		}
	}
	
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Long getSourceId() {
		return sourceId;
	}

	public void setSourceId(Long sourceId) {
		this.sourceId = sourceId;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public String getPlace() {
		return place;
	}

	public void setPlace(String place) {
		this.place = place;
	}

	public Long getDuibaScheduledTaskId() {
		return duibaScheduledTaskId;
	}

	public void setDuibaScheduledTaskId(Long duibaScheduledTaskId) {
		this.duibaScheduledTaskId = duibaScheduledTaskId;
	}

	public Date getExcuteTime() {
		return excuteTime;
	}

	public void setExcuteTime(Date excuteTime) {
		this.excuteTime = excuteTime;
	}

	public Integer getExcuteStatus() {
		return excuteStatus;
	}

	public void setExcuteStatus(Integer excuteStatus) {
		this.excuteStatus = excuteStatus;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}

==> duiba-service-api-1.8.2.5-sources.jar: cn/com/duiba/service/domain/dataobject/AppScheduledTasksDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

/**
 * app计划任务
 */
public class AppScheduledTasksDO extends BaseDO {
	private static final long serialVersionUID = 7893131267L;

	public static final String TYPE_VIRTUAL = "virtual";	//虚拟商品（仅限appItemDO使用）
	public static final String TYPE_COUPON = "coupon"; // 优惠券
	public static final String TYPE_OBJECT = "object"; // 实物
	public static final String TYPE_DUIBA_TURNTABLE = "duibaTurntable"; // 兑吧大转盘
	public static final String TYPE_DUIBA_SINGLE_LOTTERY = "duibaSingleLottery"; // 兑吧单品抽奖
	public static final String TYPE_DUIBA_ACTIVITY = "duibaActivity"; // 专题活动
	public static final String TYPE_APP_TURNTABLE = "appTurntable"; // 自有大转盘
	public static final String TYPE_APP_SINGLE_LOTTERY = "appSingleLottery"; // 自有单品抽奖
	public static final String TYPE_APP_MANUAL_LOTTERY = "appManualLottery"; // 自有手动开奖
	public static final String TYPE_DUIBA_SHAKE = "duibaShake";	// duiba摇一摇
	public static final String TYPE_APP_SHAKE = "appShake";	// app自有摇一摇
	public static final String TYPE_DUIBA_SCRATCH_CARD = "duibaScratch";//duiba刮刮乐
	public static final String TYPE_DUIBA_TIGER = "duibaTiger";//老虎机
	public static final String TYPE_DUIBA_FLOP = "duibaFlop";//趣味翻牌
	public static final String TYPE_DUIBA_SMASHG = "duibaSmashg";//砸彩蛋
	//Start chaijiangang,幸运转盘改为活动工具,2016/04/26
    public static final String TYPE_DUIBA_HDTOOL_TURNTABLE = "duibaHdToolTurntable";//兑吧活动工具幸运转盘
	public static final String TYPE_APP_HDTOOL_TURNTABLE = "appHdToolTurntable";//app自有幸运转盘
    //End chaijiangang,幸运转盘改为活动工具,2016/04/26
	public static final String TYPE_APP_SCRATCH_CARD = "appScratch";//app刮刮乐
	public static final String TYPE_APP_TIGER = "appTiger";//老虎机
	public static final String TYPE_APP_FLOP = "appFlop";//趣味翻牌
	public static final String TYPE_APP_SMASHG = "appSmashg";//砸彩蛋
	public static final String TYPE_GAME_SANTA = "gameSanta";	// 游戏圣诞
	public static final String TYPE_GAME_YEAR_AWARD = "gameYearAward";	//数 年终奖
	public static final String TYPE_GAME_GIRL = "gameGirl";	// 女神游戏
	public static final String TYPE_GAME_JIONG = "gameJiong";	// 人在囧途
	public static final String TYPE_DUIBA_SECONDS_KILL_ACTIVITY = "duibaSecondsKillActivity";	// 秒杀专题
	public static final String TYPE_DUIBA_QUESTION = "duibaQuestion";	// 兑吧答题活动
	public static final String TYPE_DUIBA_QUIZZ = "duibaQuizz";//兑吧测试题活动
	public static final String TYPE_DUIBA_SECKILL = "duibaSeckill";	// 兑吧秒杀活动
	public static final String TYPE_DUIBA_NGAME = "duibaNgame";	// 兑吧新游戏
	public static final String TYPE_DUIBA_GUESS = "duibaGuess";    // 兑吧竞猜
	public static final String TYPE_DUIBA_CREDITGAME = "creditGame";//兑吧积分游戏

	public static final String SOURCE_TYPE_ITEM = "item"; // 来源item
	public static final String SOURCE_TYPE_ACTIVITY = "activity"; // 来源activity
	
	public static final String PLACE_BANNER = "placeBanner"; // banner
	public static final String PLACE_ITEM = "placeItem"; // item
	public static final String PLACE_BANNERANDITEM = "placeBannerAndItem"; // bannerAndItem
	
	public static final int EXCUTE_STATUS_REMOVE = 0;	// 移除
	public static final int EXCUTE_STATUS_WAIT_EXCUTE = 1;	// 待执行
	public static final int EXCUTE_STATUS_EXCUTE_SUCCESS = 2;	// 执行成功
	public static final int EXCUTE_STATUS_EXCUTE_FAIL = 3;	// 执行失败
	
	private Long id;

	private Long appId;

	private String type; // 定时内容类型

	private Long sourceId;

	private String sourceType; // 资源类型

	private String place;

	private Long duibaScheduledTaskId; // 兑吧任务ID

	private Date excuteTime; // 任务执行时间

	private Integer excuteStatus; // 执行状态

	private Date gmtCreate;

	private Date gmtModified;

	public AppScheduledTasksDO() {
	}
	
	public AppScheduledTasksDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public AppScheduledTasksDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			gmtCreate = new Date();
			gmtModified = gmtCreate;
		}
	}
	
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Long getSourceId() {
		return sourceId;
	}

	public void setSourceId(Long sourceId) {
		this.sourceId = sourceId;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public String getPlace() {
		return place;
	}

	public void setPlace(String place) {
		this.place = place;
	}

	public Long getDuibaScheduledTaskId() {
		return duibaScheduledTaskId;
	}

	public void setDuibaScheduledTaskId(Long duibaScheduledTaskId) {
		this.duibaScheduledTaskId = duibaScheduledTaskId;
	}

	public Date getExcuteTime() {
		return excuteTime;
	}

	public void setExcuteTime(Date excuteTime) {
		this.excuteTime = excuteTime;
	}

	public Integer getExcuteStatus() {
		return excuteStatus;
	}

	public void setExcuteStatus(Integer excuteStatus) {
		this.excuteStatus = excuteStatus;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}
